@@ -51,9 +51,6 @@
 #include <sys/wait.h>
 #endif
 #include <errno.h>
-#ifdef MEASURE_STOP_THE_WORLD_PAUSE
-#include <time.h>
-#endif
 
 #include "runtime.h"
 #include "arch.h"
@@ -948,6 +945,16 @@ undo_fake_foreign_function_call(os_context_t __attribute__((unused)) *context)
 void save_context_for_ldb(os_context_t *context) {
     struct thread *thread = get_sb_vm_thread();
 
+#ifdef reg_CSP
+    lispobj * cfp = (lispobj*)*os_context_register_addr(context, reg_CFP);
+    lispobj * csp = (lispobj*)*os_context_register_addr(context, reg_CSP);
+    if (!(cfp >= thread->control_stack_start && cfp <= thread->control_stack_end &&
+          csp >= thread->control_stack_start && csp <= thread->control_stack_end)) {
+        save_interrupt_context(thread, context);
+        return;
+    }
+#endif
+
     if(!foreign_function_call_active_p(thread))
         fake_foreign_function_call(context);
     else
@@ -1007,15 +1014,13 @@ interrupt_handle_pending(os_context_t *context)
 #ifdef ADDRESS_SANITIZER
     __asan_unpoison_memory_region(context, sizeof *context);
 #endif
-    /* There are three ways we can get here. First, if an interrupt
+    /* There are a few ways we can get here. First, if an interrupt
      * occurs within pseudo-atomic, it will be deferred, and we'll
      * trap to here at the end of the pseudo-atomic block. Second, if
      * the GC (in alloc()) decides that a GC is required, it will set
      * *GC-PENDING* and pseudo-atomic-interrupted if not *GC-INHIBIT*,
      * and alloc() is always called from within pseudo-atomic, and
-     * thus we end up here again. Third, when calling GC-ON or at the
-     * end of a WITHOUT-GCING, MAYBE-HANDLE-PENDING-GC will trap to
-     * here if there is a pending GC. Fourth, ahem, at the end of
+     * thus we end up here again. Or at the end of
      * WITHOUT-INTERRUPTS (bar complications with nesting).
      *
      * A fourth way happens with safepoints: In addition to a stop for
@@ -1453,10 +1458,7 @@ sig_stop_for_gc_handler(int __attribute__((unused)) signal,
      * we wish to support has no problem with sem_wait() here in the signal handler. */
 
     int my_state = thread_wait_until_not(STATE_STOPPED, thread);
-#ifdef MEASURE_STOP_THE_WORLD_PAUSE
-    extern void thread_accrue_stw_time(struct thread*,struct timespec*,struct timespec*);
     thread_accrue_stw_time(thread, &t_beginpause, 0);
-#endif
 
     if (!thread->state_word.control_stack_guard_page_protected) {
         protect_control_stack_return_guard_page(1, thread);
@@ -1756,8 +1758,8 @@ void lower_thread_alien_stack_guard_page(struct thread *th)
 
 void reset_thread_alien_stack_guard_page(struct thread *th)
 {
-    protect_alien_stack_guard_page(1, NULL);
-    protect_alien_stack_return_guard_page(0, NULL);
+    protect_alien_stack_guard_page(1, th);
+    protect_alien_stack_return_guard_page(0, th);
     th->state_word.alien_stack_guard_page_protected = 1;
     fprintf(stderr, "INFO: Alien stack guard page reprotected\n");
 }
@@ -1773,8 +1775,8 @@ void lower_thread_binding_stack_guard_page(struct thread *th)
 
 void reset_thread_binding_stack_guard_page(struct thread *th)
 {
-    protect_binding_stack_guard_page(1, NULL);
-    protect_binding_stack_return_guard_page(0, NULL);
+    protect_binding_stack_guard_page(1, th);
+    protect_binding_stack_return_guard_page(0, th);
     th->state_word.binding_stack_guard_page_protected = 1;
     fprintf(stderr, "INFO: Binding stack guard page reprotected\n");
 }
@@ -2086,6 +2088,10 @@ interrupt_init(void)
 #ifndef LISP_FEATURE_WIN32
     ll_install_handler(SIGABRT, sigabrt_handler);
 #endif
+#ifdef START_LDB_SERVICE_THREAD
+    extern void init_ldb_service();
+    init_ldb_service();
+#endif
 }
 
 void lisp_memory_fault_warning(os_context_t *context, os_vm_address_t addr) {
